// $Id: EthernetEncoding.java,v 1.4 2001/05/27 21:15:21 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * Ethernet packet encoding.
 * <p>
 * Contains link-level information encoding information for an 
 * ethernet packet. 
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.4 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/27 21:15:21 $
 */
public class EthernetEncoding
{
  /**
   * EthernetPacket factory.
   */
  public static EthernetPacket create(int lLen, byte [] bytes) {
    String msa = EthernetEncoding.extractMACAddress(lLen, true, bytes); 
    String mda = EthernetEncoding.extractMACAddress(lLen, false, bytes); 

    return new EthernetPacket(lLen, bytes, msa, mda);
  }

  /**
   * Extract the type field from packet data.
   * The type field indicates what type of data is contained in the 
   * packet's data block.
   * @param packetBytes packet bytes.
   * @return the ethernet type code. i.e. 0x800 signifies IP datagram.
   */
  public static int extractTypeCode(byte [] packetBytes) {
    // convert the bytes that contain the type code into a value..
    return 
      packetBytes[ET_CODE_POS] << 8 | 
      packetBytes[ET_CODE_POS + 1];
  }

  /**
   * Extract a MAC address from an ethernet header.
   * @param sourceFlag whether the extract query is for the source address.
   * @param packetBytes packet bytes.
   */
  public static String extractMACAddress(int lLen, 
                                         boolean sourceFlag, 
                                         byte [] packetBytes) {
    if(lLen == 0)
      return "dummy" + (sourceFlag ? "_src" : "_dst");

    int offset = sourceFlag ? MAC_SRC_POS : MAC_DST_POS;
    return MACAddress.extract(offset, packetBytes);
  }


  /**
   * Position of the destination MAC address within the ethernet header.
   */
  private final static int MAC_DST_POS = 0;

  /**
   * Position of the source MAC address within the ethernet header.
   */
  private final static int MAC_SRC_POS = MACAddress.WIDTH;

  /**
   * Position of the ethernet type field within the ethernet header.
   */
  private final static int ET_CODE_POS = MACAddress.WIDTH * 2;

  private String _rcsid = 
    "$Id: EthernetEncoding.java,v 1.4 2001/05/27 21:15:21 pcharles Exp $";
}
